@@ -432,10 +432,14 @@ int ScriptCompiler::compile(const char *scrname)
 	char *ext;
 
 #ifdef	WIN32
+	char *l1, *l2;
 	setString(buffer, sizeof(buffer), scrname);
-	token = strrchr(buffer, '\\');
-	if(!token)
-			token = strrchr(buffer, '/');
+	l1 = strrchr(buffer, '/');
+	l2 = strrchr(buffer, '\\');
+	if(l1 > l2)
+		token = l1;
+	else
+		token = l2;
 #else
 	setString(buffer, sizeof(buffer), scrname);
 	token = strrchr(buffer, '/');
@@ -588,7 +592,16 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 
 	gvarlen = strlen(gvarname);
 
+#ifdef	WIN32
+	char *l1 = strrchr(scrname, '/');
+	char *l2 = strrchr(scrname, '\\');
+	if(l1 > l2)
+		cp = l1;
+	else
+		cp = l2;
+#else
 	cp = (char *)strrchr(scrname, '/');
+#endif
 	if(cp)
 		++cp;
 	else
