@@ -723,7 +723,7 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 {
 	const char *scrname = scr->name;
 	ScriptImage::InitialList *ilist;
-	ScriptBinder *mod = ScriptBinder::first;
+	ScriptBinder *mod;
 	Name *init;
 	Line *line;
 	stack = 0;
@@ -731,6 +731,7 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 	exiting = initialized = false;
 	session = this;
 	thread = NULL;
+	bool selected = false;
 	
 	image = img;
 
@@ -748,6 +749,7 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 	}
 
 	setSymbol("script.home", scrname);
+	mod = ScriptBinder::first;
 	while(mod)
 	{
 		mod->attach(this);
@@ -769,6 +771,17 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 
 	enterMutex();
 	initRuntime(scr);
+
+	mod = ScriptBinder::first;
+	while(mod && !selected)
+	{
+		selected = mod->select(this);
+		mod = mod->next;
+	}
+
+	if(selected)
+		goto finish;
+
 	if(fastStart)
 	{
 		image->fastBranch(this);
@@ -971,8 +984,7 @@ bool ScriptInterp::redirect(bool evflag)
 	if(!stricmp(frame[stack].line->cmd, "call"))
 		fun = true;
 
-	if(scr->access == scrFUNCTION)
-		isfun = true;
+	isfun = isFunction(scr);
 
 	if(!label)
 	{
@@ -1045,20 +1057,20 @@ script:
 		error("script-not-found");
 		return true;
 	}
-	if(pvt && scr->access == scrPRIVATE)
+	if(pvt && isPrivate(scr))
 	{
 		logmissing(label, "access", "script");
 		error("script-private");
 		return true;
 	}
-	if(!isfun && !fun && scr->access == scrFUNCTION && scr != frame[stack].script)
+	if(!isfun && !fun && isFunction(scr) && scr != frame[stack].script)
 	{
 		logmissing(label, "access", "script");
 		error("script-function");
 		return true;
 	}
 
-	if(scr->access != scrFUNCTION)
+	if(!isFunction(scr))
 		isfun = false;
 
 	if(isfun && evflag)
