@@ -53,7 +53,7 @@ bool ScriptMethods::scrIf(void)
         if(conditional())
 	{
 		if(frame[stack].index < frame[stack].line->argc)
-			return scrGoto();
+			return intGoto();
 		skip();
 		if(frame[stack].line->scr.method == (Method)&ScriptMethods::scrThen)
 			skip();
@@ -517,6 +517,8 @@ bool ScriptMethods::scrSet(void)
 	Line *line = getLine();
 	bool cat = false;
 	bool rtn;
+	bool pset = false;
+	unsigned ss = stack;
 
 	if(opt && isdigit(*opt))
 		size = atoi(opt);
@@ -538,8 +540,18 @@ bool ScriptMethods::scrSet(void)
 	while(NULL != (opt = getValue(NULL)))
 		addString(buffer, max + 1, opt);
 
+	if(!stricmp(line->cmd, "pset"))
+		pset = true;
+
 	opt = buffer;
+	while(pset && stack)
+	{
+		--stack;
+		if(frame[stack].local != frame[stack + 1].local)
+			break;
+	}
 	sym = mapSymbol(id, size);
+	stack = ss;
 	if(!stricmp(line->cmd, "cat") || !stricmp(line->cmd, "add"))
 		cat = true;
 	else if(!strnicmp(line->cmd, "init", 4))
@@ -731,9 +743,32 @@ bool ScriptMethods::scrThrow(void)
 }
 
 bool ScriptMethods::scrGoto(void)
+{
+	unsigned argc = 0;
+	Line *line = getLine();
+	const char *var, *value;
+
+	while(argc < line->argc)
+	{
+		var = line->args[argc++];
+		if(*var != '=')
+			continue;
+
+		++var;
+		value = getContent(line->args[argc++]);
+		if(!value)
+			continue;
+
+		setSymbol(var, value, 0);
+	}
+
+	return intGoto();
+}
+
+bool ScriptMethods::intGoto(void)
 {
 	frame[stack].tranflag = false;
-	if(image->isRipple())
+	if(image->isRipple() && frame[stack].local == NULL)
 	{
 		ripple();
 		return true;
@@ -749,7 +784,7 @@ bool ScriptMethods::scrRestart(void)
 	frame[stack].caseflag = frame[stack].tranflag = false;
 	frame[stack].line = frame[stack].first = frame[stack].script->first;
 	frame[stack].index = 0;
-        if(frame[stack].script->access == scrFUNCTION)
+	if(isFunction(frame[stack].script))
                 frame[stack].tranflag = true;
 
 	return true;
@@ -1071,6 +1106,42 @@ bool ScriptMethods::scrClear(void)
 	return true;
 }
 
+bool ScriptMethods::scrType(void)
+{
+	Symbol *tsym, temp, *sym;
+	const char *cp = getOption(NULL);
+
+	tsym = mapSymbol(cp, 0);
+	if(!tsym)
+	{
+		error("symtype-missing");
+		return true;
+	}
+
+	while(NULL != (cp = getOption(NULL)))
+	{
+		sym = mapSymbol(cp, tsym->size);
+		if(!sym)
+			continue;
+
+		if(sym->type != symINITIAL && sym->type != tsym->type)
+			continue;
+
+		if(sym->size != tsym->size)
+			continue;
+
+		temp.id = sym->id;
+		temp.next = sym->next;
+
+		memcpy(sym, tsym, sizeof(Symbol) + tsym->size);
+		sym->id = temp.id;
+		sym->next = temp.next;
+	}
+
+	advance();
+	return true;
+}
+
 bool ScriptMethods::scrVar(void)
 {
 	unsigned short size = symsize;
@@ -1078,8 +1149,9 @@ bool ScriptMethods::scrVar(void)
 	Symbol *sym;
 	char *errmsg = NULL;
 	Line *line = getLine();
+	const char *value = getKeyword("value");
 
-	if(!strnicmp(line->cmd, "char", 4))
+	if(!stricmp(line->cmd, "char"))
 		size = 1;
 
 	if(cp)
@@ -1103,6 +1175,8 @@ bool ScriptMethods::scrVar(void)
 			errmsg = "var-already-defined";
 			continue;
 		}
+		if(value)
+			commit(sym, value);
 	}
 
 	if(errmsg)
