@@ -187,6 +187,28 @@ bool Script::isSymbol(const char *id)
 	return false;
 }
 
+bool Script::isFunction(Name *scr)
+{
+	switch(scr->access)
+	{
+	case scrFUNCTION:
+	case scrLOCAL:
+		return true;
+	}
+	return false;
+}
+
+bool Script::isPrivate(Name *scr)
+{
+	switch(scr->access)
+	{
+	case scrLOCAL:
+	case scrPRIVATE:
+		return true;
+	}
+	return false;
+}
+
 unsigned Script::getIndex(const char *id)
 {
         unsigned int key = 0;
